Package: writexl
Type: Package
Title: Export Data Frames to Excel 'xlsx' Format
Version: 1.5.4
Authors@R: c(
    person("Jeroen", "Ooms", ,"jeroenooms@gmail.com", role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-4035-0289")),
    person("John McNamara", role = "cph",
      comment = "Author of libxlsxwriter (see AUTHORS and COPYRIGHT files for details)"))
Description: Zero-dependency data frame to xlsx exporter based on 'libxlsxwriter'
    <https://libxlsxwriter.github.io>. Fast and no Java or Excel required.
License: BSD_2_clause + file LICENSE
Encoding: UTF-8
URL: https://ropensci.r-universe.dev/writexl
        https://docs.ropensci.org/writexl/
BugReports: https://github.com/ropensci/writexl/issues
RoxygenNote: 7.0.2
Suggests: spelling, readxl, nycflights13, testthat, bit64
Language: en-US
SystemRequirements: zlib
NeedsCompilation: yes
Packaged: 2025-04-15 13:34:41 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>),
  John McNamara [cph] (Author of libxlsxwriter (see AUTHORS and COPYRIGHT
    files for details))
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2025-04-15 14:40:03 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 09:21:15 UTC; unix
Archs: writexl.so.dSYM
