Package: writexl
Type: Package
Title: Export Data Frames to Excel 'xlsx' Format
Version: 2.0.0
Authors@R: c(
    person("Jeroen", "Ooms", role = "aut", comment = c(ORCID = "0000-0002-4035-0289")),
    person("Bill", "Denney", ,"wdenney@humanpredictions.com", role = c("aut", "cre"),
      comment = c(ORCID="0000-0002-5759-428X")),
    person("John McNamara", role = "cph",
      comment = "Author of libxlsxwriter (see AUTHORS and COPYRIGHT files for details)"))
Description: Zero-dependency data frame to xlsx exporter based on 'libxlsxwriter'
    <https://libxlsxwriter.github.io>. Fast and no Java or Excel required.
License: BSD_2_clause + file LICENSE
Copyright: Jeroen Ooms. For copyright notices of bundled third-party
        code (libxlsxwriter and dependencies), see COPYRIGHT.
Encoding: UTF-8
URL: https://ropensci.r-universe.dev/writexl
        https://docs.ropensci.org/writexl/
BugReports: https://github.com/ropensci/writexl/issues
Suggests: grDevices, graphics, spelling, readxl, nycflights13, testthat
        (>= 3.2.0), xml2, bit64, knitr, rmarkdown
VignetteBuilder: knitr
Language: en-US
SystemRequirements: zlib
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-08-05 12:30:06 UTC; bill
Author: Jeroen Ooms [aut] (ORCID: <https://orcid.org/0000-0002-4035-0289>),
  Bill Denney [aut, cre] (ORCID: <https://orcid.org/0000-0002-5759-428X>),
  John McNamara [cph] (Author of libxlsxwriter (see AUTHORS and COPYRIGHT
    files for details))
Maintainer: Bill Denney <wdenney@humanpredictions.com>
Repository: CRAN
Date/Publication: 2026-08-05 14:50:02 UTC
