# Generated by roxygen2: do not edit by hand

S3method("+",xl_format)
S3method("[",xl_cell_general)
S3method("[<-",xl_cell_general)
S3method("[[",xl_cell_general)
S3method("[[<-",xl_cell_general)
S3method("length<-",xl_cell_general)
S3method(as.character,xl_cell_general)
S3method(as.character,xl_rich_string)
S3method(as.data.frame,xl_cell_general)
S3method(c,xl_cell_general)
S3method(format,xl_rich_string)
S3method(length,xl_cell_general)
S3method(print,xl_cell_general)
S3method(print,xl_chart)
S3method(print,xl_chart_axis)
S3method(print,xl_chart_error_bars)
S3method(print,xl_chart_label)
S3method(print,xl_chart_labels)
S3method(print,xl_chart_legend)
S3method(print,xl_chart_marker)
S3method(print,xl_chart_series)
S3method(print,xl_chart_table)
S3method(print,xl_chart_trendline)
S3method(print,xl_chartsheet)
S3method(print,xl_comment)
S3method(print,xl_conditional)
S3method(print,xl_filter)
S3method(print,xl_format)
S3method(print,xl_image)
S3method(print,xl_merge)
S3method(print,xl_outline)
S3method(print,xl_page_setup)
S3method(print,xl_properties)
S3method(print,xl_rich_run)
S3method(print,xl_rich_string)
S3method(print,xl_sheet)
S3method(print,xl_sheet_view)
S3method(print,xl_table)
S3method(print,xl_table_column)
S3method(print,xl_validation)
S3method(print,xl_workbook)
S3method(rep,xl_cell_general)
export(is_xl_comment)
export(is_xl_format)
export(is_xl_rich_string)
export(lxw_version)
export(write_xlsx)
export(xl_align)
export(xl_border)
export(xl_cell_general)
export(xl_chart)
export(xl_chart_axis)
export(xl_chart_error_bars)
export(xl_chart_label)
export(xl_chart_labels)
export(xl_chart_legend)
export(xl_chart_marker)
export(xl_chart_series)
export(xl_chart_table)
export(xl_chart_trendline)
export(xl_chartsheet)
export(xl_col_spec)
export(xl_color)
export(xl_comment)
export(xl_cond_bar)
export(xl_cond_cell)
export(xl_cond_icons)
export(xl_cond_scale)
export(xl_fill)
export(xl_filter)
export(xl_filter_keep)
export(xl_font)
export(xl_format)
export(xl_formula)
export(xl_hyperlink)
export(xl_hyperlink_cell)
export(xl_image)
export(xl_merge)
export(xl_num_format)
export(xl_outline)
export(xl_page_setup)
export(xl_properties)
export(xl_protection)
export(xl_rich_run)
export(xl_rich_string)
export(xl_row_spec)
export(xl_sheet)
export(xl_sheet_view)
export(xl_table)
export(xl_table_column)
export(xl_validation)
export(xl_workbook)
useDynLib(writexl,C_lxw_version)
useDynLib(writexl,C_set_tempdir)
useDynLib(writexl,C_write_data_frame_list)
