% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xl_comment.R
\name{is_xl_comment}
\alias{is_xl_comment}
\title{Test whether an object is an `xl_comment`}
\usage{
is_xl_comment(x)
}
\arguments{
\item{x}{An object.}
}
\value{
`TRUE` if `x` inherits from `"xl_comment"`.
}
\description{
Test whether an object is an `xl_comment`
}
\seealso{
Other cell content:
\code{\link[=xl_cell_general]{xl_cell_general()}},
\code{\link[=xl_comment]{xl_comment()}},
\code{\link[=xl_formula]{xl_formula()}},
\code{\link[=xl_rich_run]{xl_rich_run()}},
\code{\link[=xl_rich_string]{xl_rich_string()}}
}
\concept{cell content}
