% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xl_format.R
\name{is_xl_format}
\alias{is_xl_format}
\title{Test whether an object is an `xl_format`}
\usage{
is_xl_format(x)
}
\arguments{
\item{x}{An object.}
}
\value{
`TRUE` if `x` inherits from `"xl_format"`.
}
\description{
Test whether an object is an `xl_format`
}
\seealso{
Other cell formatting:
\code{\link[=xl_color]{xl_color()}},
\code{\link[=xl_format]{xl_format()}},
\code{\link{xl_format_groups}}
}
\concept{cell formatting}
