% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/version.R
\name{lxw_version}
\alias{lxw_version}
\title{Version}
\usage{
lxw_version()
}
\description{
Shows version of bundled libxlsxwriter.
}
