% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xl_chart_extras.R
\name{xl_chart_table}
\alias{xl_chart_table}
\title{The table of values under a chart}
\usage{
xl_chart_table(
  show_keys = NA,
  horizontal_border = NA,
  vertical_border = NA,
  outline_border = NA,
  format = NULL
)
}
\arguments{
\item{show_keys}{Print each series' legend swatch in the table.}

\item{horizontal_border, vertical_border, outline_border}{Which of the grid's
borders to draw.}

\item{format}{An [xl_format()] styling the table's text --- the [xl_font()]
group only.}
}
\value{
An `xl_chart_table` object.
}
\description{
`xl_chart_table()` prints the plotted numbers in a grid beneath the chart,
which is Excel's "Data Table" chart element.  It is given to [xl_chart()] as
`data_table`.

Naming none of the grid options leaves Excel's own: horizontal, vertical and
outline borders drawn, and no legend keys.
}
\examples{
xl_chart_table()
xl_chart_table(show_keys = TRUE, vertical_border = FALSE)
}
\seealso{
[xl_chart]

Other images and charts:
\code{\link[=xl_chart]{xl_chart()}},
\code{\link[=xl_chart_axis]{xl_chart_axis()}},
\code{\link[=xl_chart_error_bars]{xl_chart_error_bars()}},
\code{\link[=xl_chart_labels]{xl_chart_labels()}},
\code{\link[=xl_chart_legend]{xl_chart_legend()}},
\code{\link[=xl_chart_marker]{xl_chart_marker()}},
\code{\link[=xl_chart_series]{xl_chart_series()}},
\code{\link[=xl_chart_trendline]{xl_chart_trendline()}},
\code{\link[=xl_chartsheet]{xl_chartsheet()}},
\code{\link[=xl_image]{xl_image()}}
}
\concept{images and charts}
